@@ -1,11 +1,11 @@
 # ============ List of structure to annotate ============
 
 LIST_STRUCTURES = [
-    "",
+    "BRAIN",
 ]
 
 DICT_SUB_STRUCTURES = {
-    "":[
+    "BRAIN":[
         'External Cerebrospial Fluid',
         'Grey Matter',
         'White Matter',
